/* SPDX-License-Identifier: GPL-2.0-or-later */
#ifndef __SOUND_SEQ_OSS_LEGACY_H
#define __SOUND_SEQ_OSS_LEGACY_H

/*
 * OSS compatible macro definitions
 *
 * Copyright (C) 2000 Abramo Bagnara <abramo@alsa-project.org>
 */

#include <linux/soundcard.h>

#ifndef SAMPLE_TYPE_AWE32
#define SAMPLE_TYPE_AWE32		0x20
#endif

#endif /* __SOUND_SEQ_OSS_LEGACY_H */

