/* SPDX-License-Identifier: GPL-2.0 OR BSD-2-Clause */

#ifndef __DT_BINDINGS_ROCKCHIP_VOP2_H
#define __DT_BINDINGS_ROCKCHIP_VOP2_H

#define ROCKCHIP_VOP2_EP_RGB0	1
#define ROCKCHIP_VOP2_EP_HDMI0	2
#define ROCKCHIP_VOP2_EP_EDP0	3
#define ROCKCHIP_VOP2_EP_MIPI0	4
#define ROCKCHIP_VOP2_EP_LVDS0	5
#define ROCKCHIP_VOP2_EP_MIPI1	6
#define ROCKCHIP_VOP2_EP_LVDS1	7
#define ROCKCHIP_VOP2_EP_HDMI1	8
#define ROCKCHIP_VOP2_EP_EDP1	9
#define ROCKCHIP_VOP2_EP_DP0	10
#define ROCKCHIP_VOP2_EP_DP1	11

#endif /* __DT_BINDINGS_ROCKCHIP_VOP2_H */
