/* SPDX-License-Identifier: GPL-2.0-only */
/*
 * uda1342.h - definition for uda1342 inputs
 *
 * Copyright 2013 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
 */

#ifndef _UDA1342_H_
#define _UDA1342_H_

/* The UDA1342 has 2 inputs */

#define UDA1342_IN1 1
#define UDA1342_IN2 2

#endif
